@@ -49,7 +49,9 @@
 ;Needed to see if lyimport / mxml import is called from inside or outside Denemo
 (define Denemo #t)
 
-
+(define DenemoWholeMeasureRestTag "WholeMeasureRest") ;several commands have to coordinate there behavior around whole measure rests, which are not built-in
+(define DenemoWholeMeasureRestCommand d-WholeMeasureRest)
+(define DenemoWholeMeasureRestParams 'WholeMeasureRest::Params)  ;these three must match for this to work.
 
 (define DenemoKeypressActivatedCommand #f) ;;;is true while a keyboard shortcut is invoking a script, unless the script has set it to #f
 
@@ -207,7 +209,8 @@
     
          (doublestroke::invokegui)) ;  DenemoKeypressActivated has been dropped as it is not working
 
-
+(define (DenemoAbbreviatedString title)
+    (html-escape (if (< (string-length title) 14) title (string-append (substring title 0 10) "..."))))
 
 ;;;;;;;;;; SetHeaderField sets a field in the movement header
 ;;;;;;;;;; the directive created is tagged Score or Movement depending on the field
@@ -229,8 +232,9 @@
      (if movement
         (set! type "Movement"))
     (set! tag (string-append type fieldname)) 
-
-    (set! current (d-DirectiveGet-header-display tag))
+    (set! current (d-DirectiveGet-header-data tag))
+    (if (not current)
+        (set! current (d-DirectiveGet-header-display tag)))
     (if (not current)
             (set! current ""))      
                     
@@ -245,7 +249,9 @@
                     (let ((movement (number->string (d-GetMovement))))
                         (if escape (set! title (scheme-escape title )))
                             (d-DirectivePut-header-override tag (logior DENEMO_OVERRIDE_TAGEDIT DENEMO_OVERRIDE_GRAPHIC))
-                            (d-DirectivePut-header-display tag (html-escape title))
+                            (d-DirectivePut-header-data tag title)
+                            
+                            (d-DirectivePut-header-display tag (DenemoAbbreviatedString title))
                             (d-DirectivePut-header-postfix tag (string-append field " = \\markup { \\with-url #'\"scheme:(d-GoToPosition " movement " 1 1 1)(d-" type fieldname ")\" "  "\"" title "\"}\n")))))
             (disp "Cancelled\n"))))
 
@@ -253,7 +259,9 @@
 (define* (SetScoreHeaderField field  #:optional (title #f) (escape #t) (full-title #f))
 (let ((current "") (tag ""))
   (set! tag (string-append "Score" (string-capitalize field)))
-  (set! current (d-DirectiveGet-scoreheader-display tag))
+  (set! current (d-DirectiveGet-scoreheader-data tag))
+  (if (not current)
+        (set! current (d-DirectiveGet-scoreheader-display tag)))
   (if (not current)
       (set! current ""))
   (if (not title)
@@ -267,7 +275,8 @@
                     (d-DirectivePut-scoreheader-override tag 0)
                     (begin
                             (d-DirectivePut-scoreheader-override tag (logior DENEMO_OVERRIDE_TAGEDIT DENEMO_OVERRIDE_GRAPHIC))
-                            (d-DirectivePut-scoreheader-display tag (html-escape title))))
+                            (d-DirectivePut-scoreheader-data tag title)
+                            (d-DirectivePut-scoreheader-display tag (DenemoAbbreviatedString title))))
             (if (not full-title)
                 (set! full-title (string-append " \\markup { \\with-url #'\"scheme:(d-" tag ")\"  "  "\"" title "\"}\n")))
             (d-DirectivePut-scoreheader-postfix tag (string-append field " = " full-title "\n"))))))
@@ -742,15 +751,26 @@
 (define (d-Enter) (eval-string (string-append "(d-" (number->string (abs (d-GetPrevailingDuration))) ")" )))
 
 
-;Radiobox is a Radio-Box list where you have a pretty name and a data type.
-;;Wants pairs, car is a string to show as radio-option, cdr is a return value and can be any data type, for example a function.
-(define (RadioBoxMenu . parameters)
+;RadioBoxMenu is a Radio-Box list where you have a pretty name and a data type.
+;;takes any number of pairs as parameters, car is a string to show as radio-option, cdr is a return value and can be any data type, for example a function.
+;;or any number of strings - returns the string chosen or #f
+;;RadioBoxList takes a list of the parameter types as above, returns chosen value or #f        
+(define (RadioBoxMenuList  parameters)
     (define answer #f)
-    (define radiostring (string-append (string-join (map (lambda (x) (car x)) parameters) stop) stop))
+    (define radiostring #f)
+    (if (string? (car parameters))
+        (set! radiostring (string-append (string-join parameters stop) stop))
+        (set! radiostring (string-append (string-join (map (lambda (x) (car x)) parameters) stop) stop)))
     (set! answer (d-GetOption radiostring))
     (if answer
-        (cdr    (list-ref  parameters (list-index (lambda (x) (equal?  answer (car x))) parameters)))
-        #f))
+        (if (string? (car parameters))
+             answer
+             (cdr (list-ref  parameters (list-index (lambda (x) (equal?  answer (car x))) parameters))))
+        #f))        
+        
+(define (RadioBoxMenu . parameters)
+    (RadioBoxMenuList parameters))
+
 
 ;Protofunction for all transpose and shift related commands
 ;; Get all notes on cursor position and create a list with new values which then exchanges the current notes on cursor position
@@ -823,7 +843,7 @@
   (d-Directive-standalone  "DenemoLink")
   (d-DirectivePut-standalone-postfix "DenemoLink" (string-append "%{" filepos "%}"))
   (d-DirectivePut-standalone-minpixels "DenemoLink" 30)
-  (d-DirectivePut-standalone-graphic "DenemoLink" "\n⬁\n\n36")
+  (d-DirectivePut-standalone-graphic "DenemoLink" "\n⬁\ndenemo\n36")
   (d-DirectivePut-standalone-gy "DenemoLink" 10)
   (d-MoveCursorRight)
   (d-RefreshDisplay))
@@ -899,7 +919,7 @@
     (set! tag (string-append tag "\n" text))
     (d-Directive-standalone tag)
     (d-DirectivePut-standalone-prefix tag "<>")
-    (d-DirectivePut-standalone-postfix tag (string-append direction "\\markup " italic bold "{" (scheme-escape text) " }"))
+    (d-DirectivePut-standalone-postfix tag (string-append direction "\\markup " italic bold "{\"" (scheme-escape text) "\" }"))
     (d-DirectivePut-standalone-grob tag "Text")
     (d-DirectivePut-standalone-display tag text)
     (d-DirectivePut-standalone-minpixels tag 30))
