@@ -4,7 +4,7 @@
       (let ((staffs ""))
 	(set! response (string->number response))
 	(let loop ((number 1))
-	  (set! staffs (string-append staffs "(d-GoToPosition #f " (number->string number) " 1 1) (d-TinyStaff)"))
+	  (set! staffs (string-append staffs "(d-GoToPosition #f " (number->string number) " 1 1) (d-SmallerStaff)"))
 	  (if (< number response)
 	      (loop (+ 1 number))))	
 	(ForAllMovements staffs)
