@@ -304,8 +304,9 @@ typedef struct
   gint midi_port; /**< midi port assigned to the staff voice */ 
   gint space_above; /**< space above the staff used in the denemo gui */
   gint space_below; /**< space below the staff used in the denemo gui */
-  GList *verses;/**< a list of text editor widgets each containing a verse */
-  GList *currentverse;/**< verse to be displayed */
+  GList *verse_views;/**< a list of text editor widgets each containing a verse */
+  GList *current_verse_view;/**< verse to be displayed */
+  GList *verses;/**< gchar of the verses, synchronized with GtkTextView buffers */
   gboolean hasfigures; /**<TRUE if the staff has had figures attached. Only one staff should have this set */
   gboolean hasfakechords; /**<TRUE if the staff has had chord symbols attached. Only one staff should have this set */
   DenemoVoice voicecontrol; /**< either controls whether this staff is displayed and printed separately or as a voice */
@@ -381,6 +382,7 @@ typedef struct command_row
   gchar* after;
   gchar* fallback;
   gchar* menupath;
+  gchar* scheme;
 } command_row;
 
 typedef enum{
@@ -388,7 +390,7 @@ typedef enum{
   COMMAND_SCHEME
 } SCRIPT_TYPE;
 
-//index of columns in the keymap command list store FIXME if you add columns you must add them in keymap_get_command_row and allocate_keymap !!!!
+//index of columns in the keymap command list store FIXME if you add columns you must add them in allocate_keymap !!!!
 enum
 {
   COL_TYPE = 0,
@@ -402,6 +404,7 @@ enum
   COL_SCRIPTTYPE,
   COL_LOCATIONS,
   COL_ROW,
+  COL_SCHEME,
   N_COLUMNS
 } COMMAND_COLS;
 
@@ -1023,6 +1026,9 @@ typedef struct DenemoProject
   gint source_width;
   gint source_height;
   gint source_scale;/* scale is x1000 */
+  /* support for time spent editing the score */
+  gint total_edit_time;/* in seconds */
+  gchar* script; /**< The script, synchronized with the view buffer */
 }DenemoProject;
 
 
@@ -1117,12 +1123,14 @@ struct DenemoRoot
   GtkWidget *menubar;/**< Main menubar to giving load/save play etc functionality */
 
   GList *continuations;
-  struct RhythmPattern *singleton_rhythms[256]; /**< rhythm patterns for the EntryToolbar */
+
+#define NB_SINGLETON_RHYTHMS 256
+  struct RhythmPattern *singleton_rhythms[NB_SINGLETON_RHYTHMS]; /**< rhythm patterns for the EntryToolbar */
   gboolean ScriptRecording;/**< TRUE when menuitems presses are being recorded as scheme script*/
   gint keyboard_state;/**< state of last keypress/release controlling MIDI in*/
   gboolean keyboard_state_locked;/**< lock against changes by shift and control keypresses */
 
-  GtkWidget *ScriptView; /**< a GtkTextView containing a scheme script */
+  GtkWidget *script_view; /**< a GtkTextView containing a scheme script */
   GList *palettes; /**< list of palettes of buttons for activating scripts */
   gchar *old_user_data_dir; /**< set in case of upgrading denemo version */
   gboolean *fatal_scheme_errors; /** Abort on scheme errors */
