@@ -137,12 +137,17 @@ stop_play_callback (gchar * thescript)
   return FALSE;
 }
 
+static gboolean do_set_playbutton (gboolean paused)
+{
+    set_playbutton (paused);
+    return FALSE;
+}
 static gboolean
 update_playbutton_callback (gboolean paused)
 {
-  gdk_threads_enter ();
-  set_playbutton (paused);
-  gdk_threads_leave ();
+  
+  g_main_context_invoke (NULL, (GSourceFunc)do_set_playbutton, paused);
+  
   return FALSE;
 }
 
@@ -666,7 +671,7 @@ midiaction (gint notenum)
     {
       stage_undo (gui->movement, ACTION_STAGE_START);
     }
-  gtk_widget_queue_draw (Denemo.scorearea);     //just for advancing the cursor.
+  draw_score_area();     //just for advancing the cursor.
   if (!(Denemo.keyboard_state & CHECKING_MASK))
     {
       if (Denemo.prefs.immediateplayback)
