@@ -195,6 +195,8 @@ nudge_downward (DenemoProject * gui)
 void
 set_width_to_work_with (DenemoProject * gui)
 {
+  if(Denemo.non_interactive)
+    return;
   GList *g;
 
   for (g = gui->movements; g; g = g->next)
@@ -744,9 +746,10 @@ gostaffdown (DenemoScriptParam * param, gboolean extend_selection)
       show_lyrics ();
       find_leftmost_allcontexts (si);
 
-      update_drawing_cache ();;
+      update_drawing_cache ();
       move_viewport_down (gui);
       set_cursor_transition ();
+    
       param->status = TRUE;
     }
   else if (param == &dummy)     //is interactive
@@ -1623,7 +1626,7 @@ dnm_insertchord (DenemoProject * gui, gint duration, input_mode mode, gboolean r
 //well, they are cached as cursortime1 and 2 in the DenemoMovement structure.
 // is the curObj->starttickofnextnote > tickspermeasure where  tickspermeasure = WHOLE_NUMTICKS * time1 / time2
 
-    if(Denemo.prefs.spillover)
+    if(Denemo.prefs.spillover && si->cursor_appending)
     { 
      DenemoObject *curObj;
     
@@ -1888,6 +1891,9 @@ insert_chordnote (DenemoProject * gui)
 void
 displayhelper (DenemoProject * gui)
 {
+  if(Denemo.non_interactive)
+    return;
+
   DenemoMovement *si = gui->movement;
   beamandstemdirhelper (si);
   showwhichaccidentals ((objnode *) si->currentmeasure->data, si->curmeasurekey, si->curmeasureaccs);
@@ -1901,7 +1907,7 @@ displayhelper (DenemoProject * gui)
     gdk_beep ();                //Signal new measures in Edit mode to catch out of step entry
 #endif
   /*gtk_widget_draw (Denemo.scorearea, NULL); */
-  gtk_widget_queue_draw (Denemo.scorearea);
+  draw_score_area();
   draw_score (NULL);
 }
 
@@ -2091,7 +2097,7 @@ addmeasureafter (GtkAction* action, G_GNUC_UNUSED DenemoScriptParam* param)
   si->currentobject = NULL;
   set_rightmeasurenum (si);
   //si->markstaffnum = 0;
-  gtk_widget_queue_draw (Denemo.scorearea);// displayhelper (Denemo.project);
+  draw_score_area();
   score_status(Denemo.project, TRUE);
   // calcmarkboundaries (si);
   /* update_hscrollbar (si); */
@@ -2112,7 +2118,7 @@ insertmeasurebefore (GtkAction* action, G_GNUC_UNUSED DenemoScriptParam* param)
   set_rightmeasurenum (si);
   si->markstaffnum = 0;
 
-  gtk_widget_queue_draw (Denemo.scorearea);// displayhelper (Denemo.project);
+  draw_score_area();// displayhelper (Denemo.project);
   score_status(Denemo.project, TRUE);
   /* update_hscrollbar (si); */
 }
@@ -2495,7 +2501,7 @@ toggle_tie (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam *
     {
       store_for_undo_change (si, curmudelaobj);
       ((chord *) curmudelaobj->object)->is_tied ^= 1;
-      gtk_widget_queue_draw (Denemo.scorearea);
+      draw_score_area();
     }
   score_status (gui, TRUE);
 }
@@ -2523,7 +2529,8 @@ gotoend (gpointer param, gboolean extend_selection)
     cursorright (NULL, param);
   else
     movecursorright (NULL, param);
-  update_drawing_cache ();;     //refresh cached values, eg current timesig
+  //refresh cached values, eg current timesig
+  update_drawing_cache ();
   find_leftmost_allcontexts (gui->movement);  //FIXME is this done in displayhelper?
   displayhelper (gui);
 }
@@ -2545,7 +2552,11 @@ gotohome (gboolean extend_selection)
   if (extend_selection)
     calcmarkboundaries (gui->movement);
   find_leftmost_allcontexts (gui->movement);
-  update_drawing_cache ();;     //refresh cached values, eg current timesig
+
+  if(!Denemo.non_interactive){
+    //refresh cached values, eg current timesig
+    update_drawing_cache ();
+  }
 }
 
 
