@@ -12,15 +12,21 @@ void add_verse (GtkAction * action, DenemoScriptParam * param);
 void delete_verse (GtkAction * action, DenemoScriptParam * param);
 void reset_lyrics (DenemoStaff * staff, gint count);
 gchar *get_text_from_view (GtkWidget * textview);
-GtkWidget *add_verse_to_staff (DenemoMovement * si, DenemoStaff * staff);
-gchar *next_syllable (gint count);
+guint add_verse_to_staff (DenemoMovement * si, DenemoStaff * staff);
+gchar *next_syllable (void);
 void install_lyrics_preview (DenemoMovement * si, GtkWidget * top_vbox);
 void hide_lyrics (void);
 void show_lyrics (void);
-gboolean lyric_change (GtkTextBuffer * buffer);
+gboolean lyric_changed_cb (GtkTextBuffer * buffer);
 void select_lyrics (void);
 gchar *get_lyrics_for_current_verse (DenemoStaff * thestaff);
 gboolean put_lyrics_for_current_verse (DenemoStaff * staff, gchar * text);
 gchar *get_lyrics_for_verse_num (gint number);
 gboolean append_lyrics_for_current_verse (DenemoStaff * thestaff, gchar * text);
+gboolean synchronize_lyric_cursor(void);
+GtkWidget* verse_get_current_view(DenemoStaff* staff);
+void verse_set_current(DenemoStaff* staff, guint id);
+guint verse_get_current(DenemoStaff* staff);
+void verse_set_current_text(DenemoStaff* staff, gchar* text);
+gchar* verse_get_current_text(DenemoStaff* staff);
 #endif
