@@ -40,7 +40,10 @@ point_to_empty_movement (DenemoProject * gui)
   DenemoMovement *newscore = (DenemoMovement *) g_malloc0 (sizeof (DenemoMovement));
   init_score (newscore, gui);
   if (!Denemo.non_interactive && gui->movement && gui->movement->buttonbox)
-    gtk_widget_hide (gui->movement->buttonbox);
+        gtk_widget_hide (gui->movement->buttonbox);
+
+  if (!Denemo.non_interactive && (gui->movement) && gui->movement->lyricsbox)
+        gtk_widget_hide (gui->movement->lyricsbox); 
   g_static_mutex_lock (&smfmutex);
   gui->movement = newscore;
   g_static_mutex_unlock (&smfmutex);
@@ -74,6 +77,9 @@ void set_movement_selector (DenemoProject *gui)
   GtkWidget *button;
   GList *g;
   gint i;
+
+  if(Denemo.non_interactive)
+    return;
   
   if(gui->movements_selector)
       gtk_widget_destroy (gui->movements_selector);
@@ -99,12 +105,12 @@ void set_movement_selector (DenemoProject *gui)
   }
   for (g=gui->movements, i=1;g;g=g->next, i++)
     {
-        if(i<first)
-            continue;
-        if(i>last)
-            continue;
-        button = gtk_button_new_with_label("");
-        if (g->data == gui->movement)
+      if(i<first)
+          continue;
+      if(i>last)
+          continue;
+      button = gtk_button_new_with_label("");
+      if (g->data == gui->movement)
         {
             gchar *text = g_strdup_printf("<span foreground=\"blue\"><i><b>%d</b></i></span>", i);
             GtkWidget *label_widget = gtk_bin_get_child(GTK_BIN(button));
@@ -114,7 +120,8 @@ void set_movement_selector (DenemoProject *gui)
             text = g_strdup_printf(_("This is the current movement number %d\nClick on another button to change movements"), i);
             gtk_widget_set_tooltip_text (button, text);
             g_free(text);
-        } else 
+        } 
+      else 
         {
             gchar *more = "";
             if((last<num_movements) && (i==last))
@@ -135,7 +142,16 @@ void set_movement_selector (DenemoProject *gui)
     }
     if(i==2) 
         gtk_widget_hide (gui->movements_selector);
+    if(gui->movement)
+        set_master_tempo (gui->movement, 1.0);   
+    
+   
+    if ((gui->movement) && gui->movement->lyricsbox && Denemo.prefs.lyrics_pane)
+      gtk_widget_show (gui->movement->lyricsbox);
+    
+  
 }
+
 static void
 new_movement (GtkAction * action, DenemoScriptParam * param, gboolean before)
 {
@@ -147,7 +163,7 @@ new_movement (GtkAction * action, DenemoScriptParam * param, gboolean before)
   gui->movements = g_list_insert (gui->movements, newsi, before ? pos : pos + 1);
   newsi->currentmovementnum = 1 + g_list_index (gui->movements, newsi);
   setcurrentprimarystaff (gui->movement);
-  gui->movements_selector = NULL;
+  //gui->movements_selector = NULL;
   set_movement_selector (gui);
   
   rewind_audio ();
@@ -186,11 +202,13 @@ append_movement (GtkAction * action, gpointer param, gboolean populate)
   set_rightmeasurenum (gui->movement);
   find_leftmost_allcontexts (gui->movement);
   set_bottom_staff (gui);
-  update_hscrollbar (gui);
-  update_vscrollbar (gui);
-  gtk_widget_queue_draw (Denemo.scorearea);
-  g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
-  g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
+  if(!Denemo.non_interactive){
+    update_hscrollbar (gui);
+    update_vscrollbar (gui);
+    draw_score_area();
+    g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
+    g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
+  }
   displayhelper (gui);
   score_status (gui, TRUE);
 }
@@ -313,11 +331,19 @@ goto_movement_staff_obj (DenemoProject * possible_gui, gint movementnum, gint st
             warningdialog (_("No such movement"));
           return FALSE;
         }
-      gtk_widget_hide (gui->movement->buttonbox);
+         
+      if(!Denemo.non_interactive)
+        {
+        gtk_widget_hide (gui->movement->buttonbox);
+        if ((gui->movement) && gui->movement->lyricsbox && Denemo.prefs.lyrics_pane)
+            gtk_widget_hide (gui->movement->lyricsbox); 
+        }
       gui->movement = this->data;
-      gtk_widget_show (gui->movement->buttonbox);
+      if(!Denemo.non_interactive)
+        gtk_widget_show (gui->movement->buttonbox);
     }
-
+    
+  set_movement_selector (gui);
 
   if (!moveto_currentstaffnum (gui, staffnum))
     {
@@ -348,11 +374,11 @@ goto_movement_staff_obj (DenemoProject * possible_gui, gint movementnum, gint st
         return FALSE;
       gui->movement->cursor_appending = TRUE;
     }
-  set_movement_selector (gui);
+
   write_status (gui);
   move_viewport_up (gui);
   move_viewport_down (gui);
-  gtk_widget_queue_draw (Denemo.scorearea);
+  draw_score_area();
   return TRUE;
 }
 
@@ -428,15 +454,19 @@ next_movement (GtkAction * action, DenemoScriptParam * param)
         warningmessage (_("This is the last movement"));
       return;
     }
-  if(Denemo.non_interactive) return;
-  gtk_widget_hide (gui->movement->buttonbox);
-  if (gui->movement->lyricsbox)
-    gtk_widget_hide (gui->movement->lyricsbox);
+  
+  if(!Denemo.non_interactive){
+    gtk_widget_hide (gui->movement->buttonbox);
+    if (gui->movement->lyricsbox)
+      gtk_widget_hide (gui->movement->lyricsbox);
+  }
   gui->movement = this->data;
-  if (gui->movement->lyricsbox && Denemo.prefs.lyrics_pane)
-    gtk_widget_show (gui->movement->lyricsbox);       //toggle_lyrics_view(NULL, NULL);
-  gtk_widget_show (gui->movement->buttonbox);
-  set_master_tempo (gui->movement, 1.0);
+
+  if(!Denemo.non_interactive){
+    if (gui->movement->lyricsbox && Denemo.prefs.lyrics_pane)
+      gtk_widget_show (gui->movement->lyricsbox);       //toggle_lyrics_view(NULL, NULL);
+    gtk_widget_show (gui->movement->buttonbox);
+  }
   set_movement_selector (gui);
   //!!!!!!!!updatescoreinfo (gui);
   //FIXME duplicate code
@@ -444,15 +474,17 @@ next_movement (GtkAction * action, DenemoScriptParam * param)
   find_leftmost_allcontexts (gui->movement);
   set_bottom_staff (gui);
 
-  update_hscrollbar (gui);
-  update_vscrollbar (gui);
-  g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
-  g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
-  write_status (gui);
-  //gtk_widget_draw (Denemo.scorearea, NULL);//KLUDGE FIXME see staffup/down
-  set_movement_transition (-MOVEMENT_WIDTH);
-  gtk_widget_queue_draw (Denemo.scorearea);
-  draw_score (NULL);
+  if(!Denemo.non_interactive){
+    update_hscrollbar (gui);
+    update_vscrollbar (gui);
+    g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
+    g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
+    write_status (gui);
+    //gtk_widget_draw (Denemo.scorearea, NULL);//KLUDGE FIXME see staffup/down
+    set_movement_transition (-MOVEMENT_WIDTH);
+    draw_score_area();
+    draw_score (NULL);
+  }
 }
 
 /**
@@ -478,32 +510,38 @@ prev_movement (GtkAction * action, DenemoScriptParam * param)
         warningmessage (_("This is the first movement"));
       return;
     }
-  if(Denemo.non_interactive) return;
-  gtk_widget_hide (gui->movement->buttonbox);
-  if (gui->movement->lyricsbox)
-    gtk_widget_hide (gui->movement->lyricsbox);
+  if(!Denemo.non_interactive){
+    gtk_widget_hide (gui->movement->buttonbox);
+    if (gui->movement->lyricsbox)
+      gtk_widget_hide (gui->movement->lyricsbox);
+  }
+  
   gui->movement = this->data;
-  if (gui->movement->lyricsbox)
-    gtk_widget_show (gui->movement->lyricsbox);       //toggle_lyrics_view(NULL, NULL);
-  gtk_widget_show (gui->movement->buttonbox);
-  set_master_tempo (gui->movement, 1.0);
-   set_movement_selector (gui);
+
+  if(!Denemo.non_interactive){
+    gtk_widget_show (gui->movement->buttonbox);
+  }
+  set_movement_selector (gui);
   //!!!!!!!!!!!!!updatescoreinfo (gui);
   //FIXME duplicate code
   set_rightmeasurenum (gui->movement);
   set_bottom_staff (gui);
 
-  update_hscrollbar (gui);
-  update_vscrollbar (gui);
-  gtk_widget_queue_draw (Denemo.scorearea);
-  g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
-  g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
+  if(!Denemo.non_interactive){
+    update_hscrollbar (gui);
+    update_vscrollbar (gui);
+    draw_score_area();
+    g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
+    g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
+  }
   write_status (gui);
   //gtk_widget_draw (Denemo.scorearea, NULL);//KLUDGE FIXME see staffup/down
   set_movement_transition (MOVEMENT_WIDTH);
 
-  gtk_widget_queue_draw (Denemo.scorearea);
-  draw_score (NULL);
+  if(!Denemo.non_interactive){
+    draw_score_area();
+    draw_score (NULL);
+  }
 }
 
 /**
@@ -684,25 +722,30 @@ clone_movement (DenemoMovement * si)
 
       if (srcStaff->leftmost_clefcontext == &srcStaff->clef)
         thestaff->leftmost_clefcontext = &thestaff->clef;
-      else
+      else{
         // has to be fixed up after the measures are done..., so do the whole thing after???
         //                                                         likewise keysig timesig
-        g_warning ("Not doing clef context yet..."), thestaff->leftmost_clefcontext = &thestaff->clef;
-
+        g_warning ("Not doing clef context yet...");
+        thestaff->leftmost_clefcontext = &thestaff->clef;
+      }
+      
       if (srcStaff->leftmost_timesig == &srcStaff->timesig)
         thestaff->leftmost_timesig = &thestaff->timesig;
-      else
+      else{
         // has to be fixed up after the measures are done..., so do the whole thing after???
         //                                                         likewise keysig timesig
-        g_warning ("Not doing timesig context yet..."), thestaff->leftmost_timesig = &thestaff->timesig;
-
+        g_warning ("Not doing timesig context yet...");
+        thestaff->leftmost_timesig = &thestaff->timesig;
+      }
+      
       if (srcStaff->leftmost_keysig == &srcStaff->keysig)
         thestaff->leftmost_keysig = &thestaff->keysig;
-      else
+      else{
         // has to be fixed up after the measures are done..., so do the whole thing after???
         //                                                         likewise keysig timesig
-        g_warning ("Not doing keysig context yet..."), thestaff->leftmost_keysig = &thestaff->keysig;
-
+        g_warning ("Not doing keysig context yet...");
+        thestaff->leftmost_keysig = &thestaff->keysig;
+      }
 
 
       thestaff->denemo_name = g_string_new (srcStaff->denemo_name->str);
@@ -731,10 +774,11 @@ clone_movement (DenemoMovement * si)
       }
 
       newscore->lyricsbox = NULL;
-      thestaff->verses = extract_verses (srcStaff->verses);
-
-      if (srcStaff->currentverse)
-        thestaff->currentverse = g_list_nth (thestaff->verses, g_list_position (srcStaff->verses, srcStaff->currentverse));
+      thestaff->verse_views = extract_verses (srcStaff->verse_views);
+      //FIXME: thestaff->verses should probably be cloned too
+      GtkTextView* verse_view = verse_get_current_view (srcStaff);
+      if (verse_view)
+        verse_set_current (thestaff, verse_get_current (srcStaff));
 
       newscore->thescore = g_list_append (newscore->thescore, thestaff);
       if (g == si->currentprimarystaff)
@@ -851,16 +895,19 @@ deletescore (GtkWidget * widget, DenemoProject * gui)
       g_string_free (gui->tabname, TRUE);
       gui->tabname = NULL;
     }
-
+  gui->total_edit_time = 0;
+  reset_editing_timer();
   point_to_new_movement (gui);
   gui->movements = g_list_append (gui->movements, gui->movement);
   reset_movement_numbers (gui);
   set_width_to_work_with (gui);
   set_rightmeasurenum (gui->movement);
-  update_hscrollbar (gui);
-  update_vscrollbar (gui);
-  gtk_widget_queue_draw (Denemo.scorearea);
-  g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
-  g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
-  force_lily_refresh (gui);
+  if(!Denemo.non_interactive){
+    update_hscrollbar (gui);
+    update_vscrollbar (gui);
+    draw_score_area();
+    g_signal_emit_by_name (G_OBJECT (Denemo.hadjustment), "changed");
+    g_signal_emit_by_name (G_OBJECT (Denemo.vadjustment), "changed");
+    force_lily_refresh (gui);
+  }
 }
