@@ -8,6 +8,7 @@
 
 #include "config.h"
 #include <denemo/denemo.h>
+#include <libxml/xmlsave.h>
 #include "core/exportxml.h"
 #include "source/source.h"
 #include "core/utils.h"
@@ -347,8 +348,7 @@ newVersesElem (xmlNodePtr curElem, xmlNsPtr ns, GList * verses, gchar * type)
   xmlNodePtr versesElem = xmlNewChild (curElem, ns, (xmlChar *) type, NULL);
   for (; verses; verses = verses->next)
     {
-      GtkWidget *textview = verses->data;
-      xmlNewTextChild (versesElem, ns, (xmlChar *) "verse", (xmlChar *) get_text_from_view (textview));
+      xmlNewTextChild (versesElem, ns, (xmlChar *) "verse", (xmlChar *) verses->data);
     }
 }
 
@@ -717,7 +717,6 @@ exportXML (gchar * thefilename, DenemoProject * gui)
   if (version_string == NULL)
     version_string = g_strdup_printf ("%d", CURRENT_XML_VERSION);
   /* Append .denemo onto the filename if necessary. */
-
   //if (strcmp (filename->str + filename->len - 7, ".denemo"))
   //  g_string_append (filename, ".denemo");
 
@@ -734,11 +733,9 @@ exportXML (gchar * thefilename, DenemoProject * gui)
   xmlSetProp (scoreElem, (xmlChar *) "version", (xmlChar *) version_string);
   /* FIXME: Put comment here ("Denemo XML file generated by..."). */
 
-  if (!Denemo.non_interactive && getNumCharsSchemeText ())
+  if (gui->script && *(gui->script) != '\0')
     {
-      gchar *text = (gchar *) getSchemeText ();
-      xmlNewTextChild (scoreElem, ns, (xmlChar *) "scheme", (xmlChar *) text);
-      g_free (text);
+      xmlNewTextChild (scoreElem, ns, (xmlChar *) "scheme", (xmlChar *) gui->script);
     }
 
   if (gui->scoreheader.directives)
@@ -764,10 +761,12 @@ exportXML (gchar * thefilename, DenemoProject * gui)
 
   newXMLIntChild (parentElem, ns, (xmlChar *) "fontsize", atoi (gui->lilycontrol.staffsize->str));
   newXMLIntChild (parentElem, ns, (xmlChar *) "orientation", gui->lilycontrol.orientation);
+  newXMLIntChild (parentElem, ns, (xmlChar *) "total-edit-time", gui->total_edit_time);
 
   if (gui->lilycontrol.directives)
     newDirectivesElem (parentElem, ns, gui->lilycontrol.directives, "score-directives");
-
+  if (gui->total_edit_time)
+    newXMLIntChild (parentElem, ns, (xmlChar *)"total-editing-time", gui->total_edit_time);
   GList *custom;
   for (custom = g_list_last (gui->custom_scoreblocks); custom; custom = custom->prev)
     {
@@ -790,6 +789,7 @@ exportXML (gchar * thefilename, DenemoProject * gui)
   if (movement_number)
     newXMLIntChild (scoreElem, ns, (xmlChar *) "movement-number", movement_number);
   GList *g;
+
   for (g = gui->movements; g; g = g->next)
     {
       DenemoMovement *si = g->data;
@@ -799,7 +799,7 @@ exportXML (gchar * thefilename, DenemoProject * gui)
       newXMLIntChild (parentElem, ns, (xmlChar *) "staffno", si->currentstaffnum);
       newXMLIntChild (parentElem, ns, (xmlChar *) "measureno", si->currentmeasurenum);
 
-      newXMLIntChild (parentElem, ns, (xmlChar *) "cursorposition", si->cursor_x - 1);
+      newXMLIntChild (parentElem, ns, (xmlChar *) "cursorposition", MAX(0, si->cursor_x));
       newXMLIntChild (parentElem, ns, (xmlChar *) "tonalcenter", get_enharmonic_position ());
 
       newXMLIntChild (parentElem, ns, (xmlChar *) "zoom", (int) (100 * si->zoom));
@@ -850,22 +850,17 @@ exportXML (gchar * thefilename, DenemoProject * gui)
               xmlSetProp (parentElem, (xmlChar *) "id", (xmlChar *) staffXMLID);
               //  curElem = xmlNewChild (parentElem, ns,
               //                       (xmlChar *) "staff-info", NULL);
-
-
-
             }
         }
 
 
-
-
       /* Output each voice. These are the DenemoStaff objects */
 
       voicesElem = xmlNewChild (mvmntElem, ns, (xmlChar *) "voices", NULL);
       for (curStaff = si->thescore; curStaff != NULL; curStaff = curStaff->next)
         {
           curStaffStruct = (DenemoStaff *) curStaff->data;
-
+          
           /* Initialize voice-wide variables. */
 
           prevTieElem = NULL;
@@ -1342,7 +1337,8 @@ exportXML (gchar * thefilename, DenemoProject * gui)
     }                           // for each movement
   /* Save the file. */
 
-  if (xmlSaveFormatFile (filename->str, doc, 1) < 0)
+  xmlSaveCtxt *ctxt = xmlSaveToFilename(filename->str, "UTF-8", XML_SAVE_FORMAT | XML_SAVE_NO_EMPTY);
+  if (!ctxt || xmlSaveDoc(ctxt, doc) < 0 || xmlSaveClose(ctxt) < 0)
     {
       g_warning ("Could not save file %s", filename->str);
       ret = -1;
