@@ -1467,6 +1467,8 @@ music_font (gchar * str)
 void
 set_title_bar (DenemoProject * gui)
 {
+  if(Denemo.non_interactive)
+    return;
   gchar *title;
   if (gui->tabname && gui->tabname->len)
     title = gui->tabname->str;
@@ -1506,6 +1508,41 @@ enshift_string (gint enshift)
     }
 }
 
+gint64 thetime;
+
+static void start_editing_timer (void)
+{
+   
+    thetime = g_get_monotonic_time ();
+    
+}
+static void stop_editing_timer (void)
+{
+    gint64 thistime = g_get_monotonic_time ();
+    if ((thetime>0) && (thetime<thistime))
+        Denemo.project->total_edit_time += (thistime - thetime)/1000000;
+}
+
+void reset_editing_timer (void)
+{
+    thetime = 0;
+}
+
+gchar *time_spent_editing()
+{
+    gint seconds =  Denemo.project->total_edit_time;
+    gint days = seconds/(24*60*60);
+    gint hours;
+    gint minutes;
+
+    seconds -= days*(24*60*60);
+    hours = (seconds/(60*60));
+    seconds -= hours*(60*60);
+    minutes = seconds/60;
+    seconds -= minutes*60;
+    return g_strdup_printf("%d days %d hours %d minutes %d seconds\n", days, hours, minutes, seconds);
+}
+
 /* set the status of the current musical score - its change count and
    title bar and status bars.
    DenemoProject *gui the musical score.
@@ -1523,16 +1560,20 @@ score_status (DenemoProject * gui, gboolean change)
       gui->movement->changecount++;
       if (just_changed)
         if(!Denemo.non_interactive)
-          set_title_bar (gui);
+            start_editing_timer();
+
     }
   else
     {
       gui->notsaved = FALSE;
       if(!Denemo.non_interactive)
-        set_title_bar (gui);
+       stop_editing_timer();
     }
   if(!Denemo.non_interactive)
-    write_status (gui);
+     {
+            set_title_bar (gui);
+            write_status (gui);
+    }
 }
 
 /**
@@ -1813,7 +1854,9 @@ display_current_object (void)
                             directive->postfix?directive->postfix->str:"");
                         
            if (gui->movement->currentobject->next == NULL && (gui->movement->currentmeasure->next == NULL))
-              g_string_assign (warning, _("This Directive is at the end of the music" "\nYou may need a closing double bar line - see Directives → barlines"));
+              g_string_assign (warning, _("This Directive is at the end of the music" 
+                "\nYou may need a closing double bar line -\n" 
+                "see Directives → Markings → Inserting Barlines"));
           }
           break;
         default:
@@ -1849,6 +1892,9 @@ display_current_object (void)
 void
 write_status (DenemoProject * gui)
 {
+  if(Denemo.non_interactive)
+    return;
+
   gint minutes = 0;
   gdouble seconds = 0.0;
   gdouble early = 0.0, late = 0.0;
@@ -1988,6 +2034,8 @@ write_status (DenemoProject * gui)
 void
 write_input_status (void)
 {
+  if(Denemo.non_interactive)
+    return;
   gtk_label_set_markup (GTK_LABEL (Denemo.input_source), Denemo.input_filters->str);
 }
 
@@ -2666,3 +2714,23 @@ find_denemo_file (DenemoDirectory dir, gchar* filename)
  
   return find_path_for_file (filename, dirs);
 }
+
+gchar *escape_scheme (gchar *input)
+{
+    gchar *c = input -1;
+    GString *out = g_string_new("");
+       for(c=input; c && *c; c++)
+        {
+            if(*c=='"')
+                g_string_append (out, "\\\\\\\""); 
+            else
+                if(*c=='\\')
+                    g_string_append(out, "\\\\");
+                else 
+                {
+                    g_string_append_printf (out, "%c", *c);
+                }
+        }
+    return g_string_free(out, FALSE); 
+}
+
