@@ -43,7 +43,7 @@ initialize_playhead (void)
 void
 region_playhead (void)
 {
-  gtk_widget_queue_draw (Denemo.scorearea);
+  draw_score_area();
 }
 
 
@@ -149,6 +149,7 @@ struct infotopass
   GList *recordednote;//list of notes when recorded audio or MIDI is present
   gint currentframe; //current frame of audio being played. (current time converted to frames (at si->recording->samplerate) and slowed down)
   gboolean highlight_next_note;//the last CHORD was the one before the currently playing one.
+  gboolean allow_duration_error; //do not indicate errors in duration of measure
 };
 
 /* count the number of syllables up to staff->leftmeasurenum */
@@ -480,7 +481,7 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
 
         if (si->currentstaffnum == itp->staffnum && itp->verse && thechord->notes && !itp->slur_stack && !thechord->is_tied)
           {
-            gchar *syllable = (gchar *) next_syllable (0);
+            gchar *syllable = (gchar *) next_syllable ();
             if (cr)
               if (syllable)
                 draw_lyric (cr, x + mudelaitem->x, y + itp->in_lowy, syllable);
@@ -566,6 +567,8 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
           itp->highy = directive->ty - 10 /* for height of text */ ;
         if ((directive->gy - 10) < itp->highy)
           itp->highy = directive->gy - 10 /* for height of text */ ;
+          if(directive->tag && *directive->tag->str == '!')
+            itp->allow_duration_error = TRUE;
       }
       break;
     case CLEF:
@@ -788,13 +791,18 @@ draw_measure (cairo_t * cr, measurenode * curmeasure, gint x, gint y, DenemoProj
         }
       /* Indicate fill status  */
 #define OPACITY (curmeasure == si->currentmeasure?0.3:0.8)
+         if(itp->allow_duration_error)
+            {
+                extra_ticks = 0;
+                itp->allow_duration_error = FALSE;
+            } 
       if (curmeasure->data)
         {
           if (extra_ticks > 0)
-            cairo_set_source_rgba (cr, 1.0, 0.6, 0.6, OPACITY);
+                cairo_set_source_rgba (cr, 1.0, 0.6, 0.6, OPACITY);
           else if ((extra_ticks < 0)/* && curmeasure->next*/)
-            cairo_set_source_rgba (cr, 0.6, 0.6, 1, OPACITY);
-#undef OPACITY
+                cairo_set_source_rgba (cr, 0.6, 0.6, 1, OPACITY);
+
           if (((extra_ticks > 0) || (extra_ticks < 0)) &&
             ((curmeasure->next && curmeasure->next->data) || ((curmeasure->next!= NULL) && (!has_cursor))))
               
@@ -808,6 +816,7 @@ draw_measure (cairo_t * cr, measurenode * curmeasure, gint x, gint y, DenemoProj
               cairo_set_source_rgb (cr, 0, 0, 0);
             }
         }
+#undef OPACITY        
       if (extra_ticks == 0)
         {
           cairo_set_source_rgb (cr, 0, 0, 0);
@@ -1244,6 +1253,12 @@ draw_playback_markers (cairo_t * cr, struct infotopass *itp, gint yy, gint line_
   itp->endposition = -1;
 }
 
+void 
+draw_score_area(){
+  if(!Denemo.non_interactive)
+    gtk_widget_queue_draw (Denemo.scorearea);
+}
+
 #define MAX_FLIP_STAGES (Denemo.prefs.animation_steps>0?Denemo.prefs.animation_steps:1)
 static gboolean
 schedule_draw (gint * flip_count)
@@ -1256,7 +1271,7 @@ schedule_draw (gint * flip_count)
     {
       return FALSE;
     }
-  gtk_widget_queue_draw (Denemo.scorearea);
+  draw_score_area();
   return TRUE;
 }
 
@@ -1320,7 +1335,7 @@ draw_score (cairo_t * cr)
   for (itp.staffnum = si->top_staff, curstaff = g_list_nth (si->thescore, si->top_staff - 1), (y += si->staffspace / 4); curstaff && itp.staffnum <= si->bottom_staff; itp.staffnum++)
     {
       DenemoStaff *staff = (DenemoStaff *) curstaff->data;
-      itp.verse = staff->currentverse ? staff->currentverse->data : NULL;
+      itp.verse = verse_get_current_view (staff);
       GdkPixbuf *StaffDirectivesPixbuf = (si->currentstaffnum == itp.staffnum) ? StaffPixbuf : StaffPixbufSmall;
       if (si->currentstaffnum == itp.staffnum)
         y += staff_transition_offset ();
@@ -1618,7 +1633,7 @@ draw_callback (cairo_t * cr)
     }
   else
     {
-      cairo_set_source_rgb (cr, 0.9, 0.9, 0.9); //gray background when key strokes are not being received.
+      cairo_set_source_rgb (cr, 0.8, 0.8, 0.8); //gray background when key strokes are not being received.
     }
   cairo_paint (cr);
 
@@ -1632,6 +1647,8 @@ draw_callback (cairo_t * cr)
 void
 update_drawing_cache (void)
 {
+  if(Denemo.non_interactive)
+    return;
   draw_score (NULL);
 }
 
