@@ -89,6 +89,7 @@ SCM scheme_set_object_display_width (SCM);
 SCM scheme_get_horizontal_position (void);
 SCM scheme_get_cursor_note (SCM);
 SCM scheme_get_cursor_note_with_octave (SCM);
+SCM scheme_get_editing_time (void);
 SCM scheme_debug_object (SCM);
 SCM scheme_destroy_scheme_init (void);
 SCM scheme_get_note_name (SCM);
@@ -98,6 +99,7 @@ SCM scheme_get_note (SCM);
 SCM scheme_get_note_from_top (SCM);
 SCM scheme_get_note_from_top_as_midi (SCM);
 SCM scheme_get_notes (SCM);
+SCM scheme_get_note_at_cursor (void);
 SCM scheme_get_dots (void);
 SCM scheme_get_note_base_duration (void);
 SCM scheme_get_note_duration (void);
@@ -192,6 +194,7 @@ SCM scheme_get_command_from_user (void);
 SCM scheme_lock_directive (SCM);
 SCM scheme_set_action_script_for_tag (SCM tag, SCM script);
 SCM scheme_put_standalone_directive (SCM tag, SCM width);
+SCM scheme_directive_change_tag (SCM tag);
 SCM scheme_text_edit_standalone_directive (SCM);
 SCM scheme_delete_object_directive (SCM);
 SCM scheme_put_text_clipboard (SCM);
@@ -300,6 +303,7 @@ SCM scheme_get_last_change (SCM);
 SCM scheme_get_menu_path (SCM);
 SCM scheme_get_checksum (SCM);
 SCM scheme_set_newbie (SCM);
+SCM scheme_synchronize_lyric_cursor (void);
 SCM scheme_get_verse (SCM);
 SCM scheme_put_verse (SCM);
 SCM scheme_append_to_verse (SCM);
